@@ -10,6 +10,7 @@ import paramiko
 
 from spur.tempdir import create_temporary_dir
 from spur.files import FileOperations
+import spur.results
 
 class SshShell(object):
     def __init__(self, hostname, username, password=None, port=22, private_key_file=None):
@@ -34,13 +35,16 @@ class SshShell(object):
                 stderr_output.append(line)
                 
             return_code = int(output[-1])
-            end = time.time()
+            # Strip the extra newline and line containing the return code
+            output_as_str = "".join(output[:-1])[:-1]
             if return_code == 0:
-                # Strip the extra newline and line containing the return code
-                output_as_str = "".join(output[:-1])[:-1]
                 return ExecutionResult(output_as_str)
             else:
-                raise subprocess.CalledProcessError(return_code, command_in_cwd)
+                raise spur.results.RunProcessError(
+                    return_code=return_code,
+                    output=output_as_str,
+                    stderr_output="".join(stderr_output)
+                )
     
     def spawn(self, *args, **kwargs):
         command_in_cwd = self._generate_run_command(*args, **kwargs)
